@@ -91,11 +91,13 @@ public class IMAPAuthentication implements AuthenticationService {
         IMAP_CONNECTIONTIMEOUT("IMAP_CONNECTIONTIMEOUT"),
         USE_FULL_LOGIN_INFO("USE_FULL_LOGIN_INFO"),
         USE_FULL_LOGIN_INFO_FOR_USER_LOOKUP("USE_FULL_LOGIN_INFO_FOR_USER_LOOKUP"),
+        USE_FULL_LOGIN_INFO_FOR_CONTEXT_LOOKUP("USE_FULL_LOGIN_INFO_FOR_CONTEXT_LOOKUP"),
         IMAP_SERVER("IMAP_SERVER"),
         IMAP_PORT("IMAP_PORT"),
         USE_MULTIPLE("USE_MULTIPLE"),
         IMAP_USE_SECURE("IMAP_USE_SECURE"),
-        IMAPAUTHENC("com.openexchange.authentication.imap.imapAuthEnc");
+        IMAPAUTHENC("com.openexchange.authentication.imap.imapAuthEnc"),
+        LOWERCASE_FOR_CONTEXT_USER_LOOKUP("LOWERCASE_FOR_CONTEXT_USER_LOOKUP");
 
         /** The name of the property */
         public final String name;
@@ -181,6 +183,16 @@ public class IMAPAuthentication implements AuthenticationService {
                 useFullLoginForUserLookup = Boolean.parseBoolean(((String) props.get(PropertyNames.USE_FULL_LOGIN_INFO_FOR_USER_LOOKUP.name)).trim());
             }
 
+            boolean useFullLoginForContextLookup = false;
+            if (props.get(PropertyNames.USE_FULL_LOGIN_INFO_FOR_CONTEXT_LOOKUP.name) != null) {
+                useFullLoginForContextLookup = Boolean.parseBoolean(((String) props.get(PropertyNames.USE_FULL_LOGIN_INFO_FOR_CONTEXT_LOOKUP.name)).trim());
+            }
+
+            boolean lowerCaseForContextUserLookup = false;
+            if (props.get(PropertyNames.LOWERCASE_FOR_CONTEXT_USER_LOOKUP.name) != null) {
+                lowerCaseForContextUserLookup = Boolean.parseBoolean(((String) props.get(PropertyNames.LOWERCASE_FOR_CONTEXT_USER_LOOKUP.name)).trim());
+            }
+
             String host = "localhost";
             if (props.get(PropertyNames.IMAP_SERVER.name) != null) {
                 host = IDNA.toASCII((String) props.get(PropertyNames.IMAP_SERVER.name));
@@ -201,7 +213,12 @@ public class IMAPAuthentication implements AuthenticationService {
 
             // Set user/context info
             String userInfo = useFullLoginForUserLookup ? splitResult.fullLoginInfo : localPart;
-            String contextInfo = splitResult.domainPart;
+            String contextInfo = useFullLoginForContextLookup ? splitResult.fullLoginInfo : splitResult.domainPart;
+            if (lowerCaseForContextUserLookup) {
+                // Use JVM's default locale
+                userInfo = userInfo.toLowerCase();
+                contextInfo = contextInfo.toLowerCase();
+            }
 
             // Support for multiple IMAP servers
             boolean secure = false;
